@@ -2,5 +2,9 @@
 
 namespace flow_network {
     BaseNetwork::BaseNetwork(int n) : dist(new int[n]), n(n), graph(n) {}
+
+    BaseNetwork::~BaseNetwork() {
+        delete[] dist;
+    }
 }
 
