@@ -8,15 +8,17 @@ namespace flow_network {
     /**
      * 费用流
      */
-    struct MinimumCostFlow: BaseNetwork {
+    struct MinimumCostFlow : BaseNetwork {
 
         int *pre, *low, *vis, clk;
 
         explicit MinimumCostFlow(int n);
 
+        ~MinimumCostFlow();
+
         bool bfs(int S, int T);
 
-        std::pair<int, int> run(int S, int T);
+        std::pair<ll, ll> run(int S, int T);
     };
 }
 
